"""This module contains the general information for PkiKeyRing ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class PkiKeyRingConsts():
    ADMIN_STATE_COMPLETED = "completed"
    ADMIN_STATE_CREATED = "created"
    ADMIN_STATE_REQ_CREATED = "reqCreated"
    ADMIN_STATE_STARTED = "started"
    ADMIN_STATE_TP_SET = "tpSet"
    CERT_STATUS_CERT_CHAIN_TOO_LONG = "certChainTooLong"
    CERT_STATUS_EMPTY_CERT = "emptyCert"
    CERT_STATUS_EXPIRED = "expired"
    CERT_STATUS_FAILED_TO_VERIFY_WITH_PRIVATE_KEY = "failedToVerifyWithPrivateKey"
    CERT_STATUS_FAILED_TO_VERIFY_WITH_TP = "failedToVerifyWithTp"
    CERT_STATUS_NOT_YET_VALID = "notYetValid"
    CERT_STATUS_REVOKED = "revoked"
    CERT_STATUS_SELF_SIGNED_CERTIFICATE = "selfSignedCertificate"
    CERT_STATUS_UNKNOWN = "unknown"
    CERT_STATUS_VALID = "valid"
    CONFIG_STATE_NOT_APPLIED = "not-applied"
    CONFIG_STATE_OK = "ok"
    INT_ID_NONE = "none"
    MODULUS_MOD2048 = "mod2048"
    MODULUS_MOD2560 = "mod2560"
    MODULUS_MOD3072 = "mod3072"
    MODULUS_MOD3584 = "mod3584"
    MODULUS_MOD4096 = "mod4096"
    MODULUS_MODINVALID = "modinvalid"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    POLICY_OWNER_UNSPECIFIED = "unspecified"
    REGEN_FALSE = "false"
    REGEN_NO = "no"
    REGEN_TRUE = "true"
    REGEN_YES = "yes"


class PkiKeyRing(ManagedObject):
    """This is PkiKeyRing class."""

    consts = PkiKeyRingConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("PkiKeyRing", "pkiKeyRing", "keyring-[name]", VersionMeta.Version101a, "InputOutput", 0x7ff, [], ["aaa", "admin"], ['pkiEp'], ['faultInst', 'pkiCertReq'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["completed", "created", "reqCreated", "started", "tpSet"], []), 
        "cert": MoPropertyMeta("cert", "cert", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, [], []), 
        "cert_status": MoPropertyMeta("cert_status", "certStatus", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["certChainTooLong", "emptyCert", "expired", "failedToVerifyWithPrivateKey", "failedToVerifyWithTp", "notYetValid", "revoked", "selfSignedCertificate", "unknown", "valid"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "config_state": MoPropertyMeta("config_state", "configState", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applied", "ok"], []), 
        "config_status_message": MoPropertyMeta("config_status_message", "configStatusMessage", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]), 
        "key": MoPropertyMeta("key", "key", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, [], []), 
        "modulus": MoPropertyMeta("modulus", "modulus", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["mod2048", "mod2560", "mod3072", "mod3584", "mod4096", "modinvalid"], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x40, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []), 
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["local", "pending-policy", "policy", "unspecified"], []), 
        "regen": MoPropertyMeta("regen", "regen", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["false", "no", "true", "yes"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x100, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "tp": MoPropertyMeta("tp", "tp", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x400, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
    }

    prop_map = {
        "adminState": "admin_state", 
        "cert": "cert", 
        "certStatus": "cert_status", 
        "childAction": "child_action", 
        "configState": "config_state", 
        "configStatusMessage": "config_status_message", 
        "descr": "descr", 
        "dn": "dn", 
        "intId": "int_id", 
        "key": "key", 
        "modulus": "modulus", 
        "name": "name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "regen": "regen", 
        "rn": "rn", 
        "status": "status", 
        "tp": "tp", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.admin_state = None
        self.cert = None
        self.cert_status = None
        self.child_action = None
        self.config_state = None
        self.config_status_message = None
        self.descr = None
        self.int_id = None
        self.key = None
        self.modulus = None
        self.policy_level = None
        self.policy_owner = None
        self.regen = None
        self.status = None
        self.tp = None

        ManagedObject.__init__(self, "PkiKeyRing", parent_mo_or_dn, **kwargs)




# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import re

import pyparsing as pp

from . import ucscgenutils
from . import ucsccoreutils
from .ucscfiltertype import OrFilter, AndFilter, NotFilter
from .ucscbasetype import FilterFilter

types = {"eq": "EqFilter",
         "ne": "NeFilter",
         "ge": "GeFilter",
         "gt": "GtFilter",
         "le": "LeFilter",
         "lt": "LtFilter",
         "re": "WcardFilter"
         }


class ParseFilter(object):
    """
    Supporting class to parse filter expression.
    """

    def __init__(self, class_id, is_meta_classid):
        self.class_id = class_id
        self.is_meta_classid = is_meta_classid

    def parse_filter_obj(self, toks):
        """
        Supporting class to parse filter expression.
        """

        prop_ = toks[0]["prop"]
        value_ = toks[0]["value"]

        type_ = "re"
        if "type_exp" in toks[0]:
            type_ = toks[0]["type_exp"]["types"]

        flag_ = "C"
        if "flag_exp" in toks[0]:
            flag_ = toks[0]["flag_exp"]["flags"]

        if flag_ == "I":
            value_ = re.sub(
                r"[a-zA-Z]",
                lambda x: "[" + x.group().upper() + x.group().lower() + "]",
                value_)

        if self.is_meta_classid:
            class_obj = ucsccoreutils.load_class(self.class_id)
            prop_mo_meta = class_obj.prop_meta[prop_]
            if prop_mo_meta:
                prop_ = prop_mo_meta.xml_attribute

        sub_filter = create_basic_filter(types[type_],
                                         class_=ucscgenutils.word_l(
                                             self.class_id),
                                         property=prop_,
                                         value=value_)

        return sub_filter

    @staticmethod
    def and_operator(toks):
        """
        method to support logical 'and' operator expression
        """

        and_filter = AndFilter()
        for op_filter in toks[0][0::2]:
            and_filter.child_add(op_filter)
        return and_filter

    @staticmethod
    def or_operator(toks):
        """
        method to support logical 'or' operator expression
        """

        or_filter = OrFilter()
        for op_filter in toks[0][0::2]:
            or_filter.child_add(op_filter)
        return or_filter

    @staticmethod
    def not_operator(toks):
        """
        method to support logical 'and' operator expression
        """

        not_filter = NotFilter()

        for op_filter in toks[0][1:]:
            not_filter.child_add(op_filter)
        return not_filter

    def parse_filter_str(self, filter_str):
        """
        method to parse filter string
        """

        prop = pp.Word(pp.alphanums + "_", asKeyword=True).setResultsName("prop")
        value = (pp.QuotedString("'")
                 | pp.QuotedString('"')
                 | pp.Word(pp.printables, excludeChars=",")
                 ).setResultsName("value")
        types_ = pp.oneOf("re eq ne gt ge lt le").setResultsName("types")
        flags = pp.Char("CI").setResultsName("flags")
        comma = pp.Literal(',')

        def in_quotes(exp):
            # ensure matching opening and closing quotes
            return ('"' + exp + '"'
                    | "'" + exp + "'")

        type_exp = pp.Group(pp.Keyword("type")
                            + pp.Literal("=")
                            + in_quotes(types_)).setResultsName("type_exp")
        flag_exp = pp.Group(pp.Keyword("flag")
                            + pp.Literal("=")
                            + in_quotes(flags)).setResultsName("flag_exp")

        semi_expression = pp.Group(pp.Literal("(") +
                                   prop + comma + value +
                                   pp.Optional(comma + type_exp) +
                                   pp.Optional(comma + flag_exp) +
                                   pp.Literal(")")
                                   ).setParseAction(
                                        self.parse_filter_obj
                                   ).setResultsName("semi_expression")

        NOT, AND, OR = map(pp.Keyword, "not and or".split())
        expr = pp.infixNotation(semi_expression, [
            (NOT, 1, pp.opAssoc.RIGHT, self.not_operator),
            (AND, 2, pp.opAssoc.LEFT, self.and_operator),
            (OR, 2, pp.opAssoc.LEFT, self.or_operator)
        ])

        result = expr.parseString(filter_str)
        return result


def generate_infilter(class_id, filter_str, is_meta_class_id):
    """
    Create FilterFilter object

    Args:
        class_id (str): class_id
        filter_str (str): filter expression
        is_meta_class_id (bool)

    Returns:
        True on successful connect

    Example:
        generate_infilter("LsServer", '("usr_lbl, "mysp", type="eq", flag="I)',
                          True)
    """

    parse_filter = ParseFilter(class_id=class_id,
                               is_meta_classid=is_meta_class_id)
    result = parse_filter.parse_filter_str(filter_str)
    in_filter = FilterFilter()
    in_filter.child_add(result[0])
    return in_filter


def handle_filter_max_component_limit(handle, l_filter):
    """
    Method checks the filter count and if the filter count exceeds
    the max_components(number of filters), then the given filter
    objects get distributed among small groups and then again binded
    together in complex filters(like and , or) so that the
    count of filters can be reduced.
    """

    from .ucsccore import AbstractFilter
    from .ucscfiltertype import AndFilter, OrFilter

    max_components = 10
    if l_filter is None or l_filter.child_count() <= max_components:
        return l_filter

    if not isinstance(l_filter, AndFilter) and not isinstance(l_filter,
                                                              OrFilter):
        return l_filter

    if isinstance(l_filter, AndFilter):
        parent_filter = AndFilter()
        child_filter = AndFilter()
        parent_filter.child_add(child_filter)
        for childf in l_filter.child:
            if isinstance(childf, AbstractFilter):
                if child_filter.child_count() == max_components:
                    child_filter = AndFilter()
                    parent_filter.child_add(child_filter)
                child_filter.child_add(childf)
        result_filter = parent_filter
    else:
        parent_filter = OrFilter()
        child_filter = OrFilter()
        parent_filter.child_add(child_filter)
        for childf in l_filter.child:
            if isinstance(childf, AbstractFilter):
                if child_filter.child_count() == max_components:
                    child_filter = OrFilter()
                    parent_filter.child_add(child_filter)
                child_filter.child_add(childf)
        result_filter = parent_filter
    return handle_filter_max_component_limit(handle, result_filter)


def create_basic_filter(filter_name, **kwargs):
    """
    Loads filter class
    """

    from . import ucscmeta
    fq_module_name = ucscmeta.OTHER_TYPE_CLASS_ID[filter_name]
    module_import = __import__(fq_module_name, globals(), locals(),
                               [filter_name], level=1)
    filter_obj = getattr(module_import, filter_name)()
    filter_obj.create(**kwargs)
    return filter_obj



"""This module contains the meta information of FabricResolveVlanPermits ExternalMethod."""

from ..ucsccoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("FabricResolveVlanPermits", "fabricResolveVlanPermits", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_action": MethodPropertyMeta("InAction", "inAction", "Xs:string", "Version142b", "Input", False),
    "in_domain_group_list": MethodPropertyMeta("InDomainGroupList", "inDomainGroupList", "DnSet", "Version142b", "Input", True),
    "in_from": MethodPropertyMeta("InFrom", "inFrom", "Xs:unsignedInt", "Version142b", "Input", False),
    "in_hierarchical": MethodPropertyMeta("InHierarchical", "inHierarchical", "Xs:string", "Version142b", "Input", False),
    "in_org_list": MethodPropertyMeta("InOrgList", "inOrgList", "DnSet", "Version142b", "Input", True),
    "in_pub_nw_name": MethodPropertyMeta("InPubNwName", "inPubNwName", "Xs:string", "Version142b", "Input", False),
    "in_to": MethodPropertyMeta("InTo", "inTo", "Xs:unsignedInt", "Version142b", "Input", False),
    "in_vlan_list": MethodPropertyMeta("InVlanList", "inVlanList", "DnSet", "Version142b", "Input", True),
    "in_vlan_name": MethodPropertyMeta("InVlanName", "inVlanName", "Xs:string", "Version142b", "Input", False),
    "in_vlan_prefix": MethodPropertyMeta("InVlanPrefix", "inVlanPrefix", "Xs:string", "Version142b", "Input", False),
    "out_result_set": MethodPropertyMeta("OutResultSet", "outResultSet", "ConfigSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "inAction": "in_action",
    "inDomainGroupList": "in_domain_group_list",
    "inFrom": "in_from",
    "inHierarchical": "in_hierarchical",
    "inOrgList": "in_org_list",
    "inPubNwName": "in_pub_nw_name",
    "inTo": "in_to",
    "inVlanList": "in_vlan_list",
    "inVlanName": "in_vlan_name",
    "inVlanPrefix": "in_vlan_prefix",
    "outResultSet": "out_result_set",
}




"""This module contains the general information for LsbootLocalHddImage ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class LsbootLocalHddImageConsts():
    TYPE_EMBEDDED_LOCAL_JBOD = "embedded-local-jbod"
    TYPE_EMBEDDED_LOCAL_LUN = "embedded-local-lun"
    TYPE_LOCAL_ANY = "local-any"
    TYPE_LOCAL_JBOD = "local-jbod"
    TYPE_LOCAL_LUN = "local-lun"
    TYPE_NVME = "nvme"
    TYPE_SD_CARD = "sd-card"
    TYPE_USB_EXTERN = "usb-extern"
    TYPE_USB_INTERN = "usb-intern"


class LsbootLocalHddImage(ManagedObject):
    """This is LsbootLocalHddImage class."""

    consts = LsbootLocalHddImageConsts()
    naming_props = set([])

    mo_meta = MoMeta("LsbootLocalHddImage", "lsbootLocalHddImage", "local-hdd", VersionMeta.Version112a, "InputOutput", 0x1f, [], ["admin", "ls-compute", "ls-config", "ls-config-policy", "ls-server", "ls-server-policy", "ls-storage", "ls-storage-policy"], ['lsbootLocalStorage'], ['lsbootLocalLunImagePath', 'lsbootUEFIBootParam'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version112a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "order": MoPropertyMeta("order", "order", "ushort", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, [], ["1-16"]), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["embedded-local-jbod", "embedded-local-lun", "local-any", "local-jbod", "local-lun", "nvme", "sd-card", "usb-extern", "usb-intern"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "order": "order", 
        "rn": "rn", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.order = None
        self.status = None
        self.type = None

        ManagedObject.__init__(self, "LsbootLocalHddImage", parent_mo_or_dn, **kwargs)




# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from nose.tools import *

import ucscsdk.ucsccoreutils as cutil


def setup_func():
    pass


def teardown_func():
    pass


@with_setup(setup_func, teardown_func)
def test_001_get_naming_props():
    rn_pattern = "fault-[code]-[name]-[type]-xyz-[state]"
    rn_str = "fault-F35275-fault-c2-xyz-on"
    np = cutil.get_naming_props(rn_str, rn_pattern)
    assert_equal(np['code'], 'F35275')
    assert_equal(np['name'], 'fault')
    assert_equal(np['type'], 'c2')
    assert_equal(np['state'], 'on')


@with_setup(setup_func, teardown_func)
def test_002_get_naming_props():
    rn_pattern = "[suport_type][card_param_type]"
    rn_str = "11"
    np = cutil.get_naming_props(rn_str, rn_pattern)
    assert_equal(np['suport_type'], '1')
    assert_equal(np['card_param_type'], '1')


@with_setup(setup_func, teardown_func)
def test_003_get_naming_props():
    rn_pattern = "[suport_type][card_param_type]"
    rn_str = "1122"
    np = cutil.get_naming_props(rn_str, rn_pattern)
    assert_equal(np['suport_type'], '112')
    assert_equal(np['card_param_type'], '2')



"""This module contains the general information for FabricFcoeSanPcOperationFsmStage ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FabricFcoeSanPcOperationFsmStageConsts():
    LAST_UPDATE_TIME_ = ""
    NAME_FIPORT_BEGIN = "FIPortBegin"
    NAME_FIPORT_CLEAN_UP = "FIPortCleanUp"
    NAME_FIPORT_FAIL = "FIPortFail"
    NAME_FIPORT_PUSH_POLICIES = "FIPortPushPolicies"
    NAME_FIPORT_PUSH_VXAN = "FIPortPushVxan"
    NAME_FIPORT_ROLE_CONFIG = "FIPortRoleConfig"
    NAME_FIPORT_SUCCESS = "FIPortSuccess"
    NAME_FIPORT_VXAN_CONFIG = "FIPortVxanConfig"
    NAME_FIPORT_WAIT = "FIPortWait"
    NAME_FIPORT_WAIT_FOR_POLICIES = "FIPortWaitForPolicies"
    NAME_NOP = "nop"
    STAGE_STATUS_FAIL = "fail"
    STAGE_STATUS_IN_PROGRESS = "inProgress"
    STAGE_STATUS_NOP = "nop"
    STAGE_STATUS_PENDING = "pending"
    STAGE_STATUS_SKIP = "skip"
    STAGE_STATUS_SUCCESS = "success"
    STAGE_STATUS_THROTTLED = "throttled"


class FabricFcoeSanPcOperationFsmStage(ManagedObject):
    """This is FabricFcoeSanPcOperationFsmStage class."""

    consts = FabricFcoeSanPcOperationFsmStageConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("FabricFcoeSanPcOperationFsmStage", "fabricFcoeSanPcOperationFsmStage", "stage-[name]", VersionMeta.Version141a, "OutputOnly", 0xf, [], [""], ['fabricFcoeSanPcOperationFsm'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "last_update_time": MoPropertyMeta("last_update_time", "lastUpdateTime", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [""], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version141a, MoPropertyMeta.NAMING, None, None, None, None, ["FIPortBegin", "FIPortCleanUp", "FIPortFail", "FIPortPushPolicies", "FIPortPushVxan", "FIPortRoleConfig", "FIPortSuccess", "FIPortVxanConfig", "FIPortWait", "FIPortWaitForPolicies", "nop"], []), 
        "order": MoPropertyMeta("order", "order", "ushort", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "retry": MoPropertyMeta("retry", "retry", "byte", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "stage_status": MoPropertyMeta("stage_status", "stageStatus", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["fail", "inProgress", "nop", "pending", "skip", "success", "throttled"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "lastUpdateTime": "last_update_time", 
        "name": "name", 
        "order": "order", 
        "retry": "retry", 
        "rn": "rn", 
        "stageStatus": "stage_status", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.last_update_time = None
        self.order = None
        self.retry = None
        self.stage_status = None
        self.status = None

        ManagedObject.__init__(self, "FabricFcoeSanPcOperationFsmStage", parent_mo_or_dn, **kwargs)




"""This module contains the general information for LicenseSourceFile ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class LicenseSourceFileConsts():
    EXP_NEVER = "never"
    TYPE_FEATURE = "feature"
    TYPE_INCREMENT = "increment"
    TYPE_UPGRADE = "upgrade"


class LicenseSourceFile(ManagedObject):
    """This is LicenseSourceFile class."""

    consts = LicenseSourceFileConsts()
    naming_props = set(['id', 'line'])

    mo_meta = MoMeta("LicenseSourceFile", "licenseSourceFile", "src-[id]:[line]", VersionMeta.Version111a, "InputOutput", 0x3f, [], ["read-only"], ['licenseInstance'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "exp": MoPropertyMeta("exp", "exp", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", ["never"], []), 
        "host_id": MoPropertyMeta("host_id", "hostId", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "id": MoPropertyMeta("id", "id", "string", VersionMeta.Version111a, MoPropertyMeta.NAMING, 0x4, 1, 32, None, [], []), 
        "line": MoPropertyMeta("line", "line", "string", VersionMeta.Version111a, MoPropertyMeta.NAMING, 0x8, 1, 510, None, [], []), 
        "pak": MoPropertyMeta("pak", "pak", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "quant": MoPropertyMeta("quant", "quant", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "sig": MoPropertyMeta("sig", "sig", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["feature", "increment", "upgrade"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "exp": "exp", 
        "hostId": "host_id", 
        "id": "id", 
        "line": "line", 
        "pak": "pak", 
        "quant": "quant", 
        "rn": "rn", 
        "sig": "sig", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, id, line, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.line = line
        self.child_action = None
        self.exp = None
        self.host_id = None
        self.pak = None
        self.quant = None
        self.sig = None
        self.status = None
        self.type = None

        ManagedObject.__init__(self, "LicenseSourceFile", parent_mo_or_dn, **kwargs)




"""This module contains the meta information of StatsBuildCustomChart ExternalMethod."""

from ..ucsccoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("StatsBuildCustomChart", "statsBuildCustomChart", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_aggregate_by_dn": MethodPropertyMeta("InAggregateByDn", "inAggregateByDn", "Xs:string", "Version142b", "Input", False),
    "in_end_time": MethodPropertyMeta("InEndTime", "inEndTime", "Xs:unsignedLong", "Version142b", "Input", False),
    "in_overlay": MethodPropertyMeta("InOverlay", "inOverlay", "Xs:string", "Version142b", "Input", False),
    "in_resolve_dns": MethodPropertyMeta("InResolveDns", "inResolveDns", "DnSet", "Version142b", "Input", True),
    "in_start_time": MethodPropertyMeta("InStartTime", "inStartTime", "Xs:unsignedLong", "Version142b", "Input", False),
    "in_stats_types": MethodPropertyMeta("InStatsTypes", "inStatsTypes", "Xs:string", "Version142b", "Input", False),
    "out_stats_query_mo": MethodPropertyMeta("OutStatsQueryMo", "outStatsQueryMo", "ConfigConfig", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "inAggregateByDn": "in_aggregate_by_dn",
    "inEndTime": "in_end_time",
    "inOverlay": "in_overlay",
    "inResolveDns": "in_resolve_dns",
    "inStartTime": "in_start_time",
    "inStatsTypes": "in_stats_types",
    "outStatsQueryMo": "out_stats_query_mo",
}




"""This module contains the general information for ComputeTemplate ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ComputeTemplateConsts():
    INSTANTIATION_STATE_BIOS_RESTORE = "bios-restore"
    INSTANTIATION_STATE_CMOS_RESET = "cmos-reset"
    INSTANTIATION_STATE_COMPUTE_FAILED = "compute-failed"
    INSTANTIATION_STATE_COMPUTE_MISMATCH = "compute-mismatch"
    INSTANTIATION_STATE_CONFIG = "config"
    INSTANTIATION_STATE_CONFIG_FAILURE = "config-failure"
    INSTANTIATION_STATE_DECOMISSIONING = "decomissioning"
    INSTANTIATION_STATE_DEGRADED = "degraded"
    INSTANTIATION_STATE_DIAGNOSTICS = "diagnostics"
    INSTANTIATION_STATE_DIAGNOSTICS_FAILED = "diagnostics-failed"
    INSTANTIATION_STATE_DISABLED = "disabled"
    INSTANTIATION_STATE_DISCOVERY = "discovery"
    INSTANTIATION_STATE_DISCOVERY_FAILED = "discovery-failed"
    INSTANTIATION_STATE_INACCESSIBLE = "inaccessible"
    INSTANTIATION_STATE_INDETERMINATE = "indeterminate"
    INSTANTIATION_STATE_INOPERABLE = "inoperable"
    INSTANTIATION_STATE_INSTANTIATED = "instantiated"
    INSTANTIATION_STATE_MAINTENANCE = "maintenance"
    INSTANTIATION_STATE_MAINTENANCE_FAILED = "maintenance-failed"
    INSTANTIATION_STATE_OK = "ok"
    INSTANTIATION_STATE_PENDING_REASSOCIATION = "pending-reassociation"
    INSTANTIATION_STATE_PENDING_REBOOT = "pending-reboot"
    INSTANTIATION_STATE_POWER_OFF = "power-off"
    INSTANTIATION_STATE_POWER_PROBLEM = "power-problem"
    INSTANTIATION_STATE_REMOVED = "removed"
    INSTANTIATION_STATE_RESTART = "restart"
    INSTANTIATION_STATE_TEST = "test"
    INSTANTIATION_STATE_TEST_FAILED = "test-failed"
    INSTANTIATION_STATE_THERMAL_PROBLEM = "thermal-problem"
    INSTANTIATION_STATE_UNASSOCIATED = "unassociated"
    INSTANTIATION_STATE_UNCONFIG = "unconfig"
    INSTANTIATION_STATE_UNCONFIG_FAILED = "unconfig-failed"
    INSTANTIATION_STATE_UNINSTANTIATED = "uninstantiated"
    INSTANTIATION_STATE_VOLTAGE_PROBLEM = "voltage-problem"
    INT_ID_NONE = "none"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    POLICY_OWNER_UNSPECIFIED = "unspecified"


class ComputeTemplate(ManagedObject):
    """This is ComputeTemplate class."""

    consts = ComputeTemplateConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("ComputeTemplate", "computeTemplate", "templ-[name]", VersionMeta.Version101a, "InputOutput", 0x3f, [], ["read-only"], ['orgOrg'], ['computeLocalTemplDef', 'lsServer'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x2, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "instantiation_state": MoPropertyMeta("instantiation_state", "instantiationState", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["bios-restore", "cmos-reset", "compute-failed", "compute-mismatch", "config", "config-failure", "decomissioning", "degraded", "diagnostics", "diagnostics-failed", "disabled", "discovery", "discovery-failed", "inaccessible", "indeterminate", "inoperable", "instantiated", "maintenance", "maintenance-failed", "ok", "pending-reassociation", "pending-reboot", "power-off", "power-problem", "removed", "restart", "test", "test-failed", "thermal-problem", "unassociated", "unconfig", "unconfig-failed", "uninstantiated", "voltage-problem"], []), 
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x8, None, None, r"""[\-\.:_a-zA-Z0-9]{1,128}""", [], []), 
        "placement_ref_cnt": MoPropertyMeta("placement_ref_cnt", "placementRefCnt", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["local", "pending-policy", "policy", "unspecified"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "instantiationState": "instantiation_state", 
        "intId": "int_id", 
        "name": "name", 
        "placementRefCnt": "placement_ref_cnt", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.instantiation_state = None
        self.int_id = None
        self.placement_ref_cnt = None
        self.policy_level = None
        self.policy_owner = None
        self.status = None

        ManagedObject.__init__(self, "ComputeTemplate", parent_mo_or_dn, **kwargs)




"""This module contains the general information for AdaptorRnicCapSpec ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class AdaptorRnicCapSpecConsts():
    MAXIMUM_UNSPECIFIED = "unspecified"
    MAXIMUM_MR_UNSPECIFIED = "unspecified"
    MAXIMUM_QP_UNSPECIFIED = "unspecified"


class AdaptorRnicCapSpec(ManagedObject):
    """This is AdaptorRnicCapSpec class."""

    consts = AdaptorRnicCapSpecConsts()
    naming_props = set(['type'])

    mo_meta = MoMeta("AdaptorRnicCapSpec", "adaptorRnicCapSpec", "cap-[type]", VersionMeta.Version141a, "InputOutput", 0x1f, [], ["read-only"], ['adaptorFruCapProvider'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "fw_version_hi": MoPropertyMeta("fw_version_hi", "fwVersionHi", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "fw_version_lo": MoPropertyMeta("fw_version_lo", "fwVersionLo", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "fw_version_opr": MoPropertyMeta("fw_version_opr", "fwVersionOpr", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "maximum": MoPropertyMeta("maximum", "maximum", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unspecified"], ["0-4294967295"]), 
        "maximum_mr": MoPropertyMeta("maximum_mr", "maximumMR", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unspecified"], ["0-4294967295"]), 
        "maximum_qp": MoPropertyMeta("maximum_qp", "maximumQP", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unspecified"], ["0-4294967295"]), 
        "nf_version_lo": MoPropertyMeta("nf_version_lo", "nfVersionLo", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version141a, MoPropertyMeta.NAMING, 0x10, None, None, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "fwVersionHi": "fw_version_hi", 
        "fwVersionLo": "fw_version_lo", 
        "fwVersionOpr": "fw_version_opr", 
        "maximum": "maximum", 
        "maximumMR": "maximum_mr", 
        "maximumQP": "maximum_qp", 
        "nfVersionLo": "nf_version_lo", 
        "rn": "rn", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, type, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.child_action = None
        self.fw_version_hi = None
        self.fw_version_lo = None
        self.fw_version_opr = None
        self.maximum = None
        self.maximum_mr = None
        self.maximum_qp = None
        self.nf_version_lo = None
        self.status = None

        ManagedObject.__init__(self, "AdaptorRnicCapSpec", parent_mo_or_dn, **kwargs)




"""This module contains the general information for IqnpoolPooled ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class IqnpoolPooledConsts():
    ASSIGNED_FALSE = "false"
    ASSIGNED_NO = "no"
    ASSIGNED_TRUE = "true"
    ASSIGNED_YES = "yes"
    CONS_CNT_ASSIGNED_TO_SINGLE = "assigned-to-single"
    CONS_CNT_AVAILABLE = "available"


class IqnpoolPooled(ManagedObject):
    """This is IqnpoolPooled class."""

    consts = IqnpoolPooledConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("IqnpoolPooled", "iqnpoolPooled", "[id]", VersionMeta.Version101a, "InputOutput", 0x1f, [], ["read-only"], ['iqnpoolPool'], [], ["Get"])

    prop_meta = {
        "assigned": MoPropertyMeta("assigned", "assigned", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "assigned_to_dn": MoPropertyMeta("assigned_to_dn", "assignedToDn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "block_dn": MoPropertyMeta("block_dn", "blockDn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "cons_cnt": MoPropertyMeta("cons_cnt", "consCnt", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["assigned-to-single", "available"], ["0-4294967295"]), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "id": MoPropertyMeta("id", "id", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x4, 1, 510, None, [], []), 
        "id_released_time": MoPropertyMeta("id_released_time", "idReleasedTime", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "poolable_dn": MoPropertyMeta("poolable_dn", "poolableDn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "prev_assigned_to_dn": MoPropertyMeta("prev_assigned_to_dn", "prevAssignedToDn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "assigned": "assigned", 
        "assignedToDn": "assigned_to_dn", 
        "blockDn": "block_dn", 
        "childAction": "child_action", 
        "consCnt": "cons_cnt", 
        "dn": "dn", 
        "id": "id", 
        "idReleasedTime": "id_released_time", 
        "poolableDn": "poolable_dn", 
        "prevAssignedToDn": "prev_assigned_to_dn", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.assigned = None
        self.assigned_to_dn = None
        self.block_dn = None
        self.child_action = None
        self.cons_cnt = None
        self.id_released_time = None
        self.poolable_dn = None
        self.prev_assigned_to_dn = None
        self.status = None

        ManagedObject.__init__(self, "IqnpoolPooled", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ConfigServerFilter ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ConfigServerFilterConsts():
    ASSOCIATION_ASSOCIATED = "associated"
    ASSOCIATION_ESTABLISHING = "establishing"
    ASSOCIATION_FAILED = "failed"
    ASSOCIATION_NONE = "none"
    ASSOCIATION_REMOVING = "removing"
    ASSOCIATION_THROTTLED = "throttled"
    CPU_ARCH_DUAL_CORE_OPTERON = "Dual-Core_Opteron"
    CPU_ARCH_INTEL_P4_C = "Intel_P4_C"
    CPU_ARCH_OPTERON = "Opteron"
    CPU_ARCH_PENTIUM_4 = "Pentium_4"
    CPU_ARCH_TURION_64 = "Turion_64"
    CPU_ARCH_XEON = "Xeon"
    CPU_ARCH_XEON_MP = "Xeon_MP"
    CPU_ARCH_ZEN = "Zen"
    CPU_ARCH_ANY = "any"
    DECOMMISSIONED_FALSE = "false"
    DECOMMISSIONED_NO = "no"
    DECOMMISSIONED_TRUE = "true"
    DECOMMISSIONED_YES = "yes"
    DISCOVERY_COMPLETE = "complete"
    DISCOVERY_DIAGNOSTICS_COMPLETE = "diagnostics-complete"
    DISCOVERY_DIAGNOSTICS_FAILED = "diagnostics-failed"
    DISCOVERY_DIAGNOSTICS_IN_PROGRESS = "diagnostics-in-progress"
    DISCOVERY_EFIDIAGNOSTICS_IN_PROGRESS = "efidiagnostics-in-progress"
    DISCOVERY_FAILED = "failed"
    DISCOVERY_FRU_IDENTITY_INDETERMINATE = "fru-identity-indeterminate"
    DISCOVERY_FRU_NOT_READY = "fru-not-ready"
    DISCOVERY_FRU_STATE_INDETERMINATE = "fru-state-indeterminate"
    DISCOVERY_ILLEGAL_FRU = "illegal-fru"
    DISCOVERY_IN_PROGRESS = "in-progress"
    DISCOVERY_INSUFFICIENTLY_EQUIPPED = "insufficiently-equipped"
    DISCOVERY_INVALID_ADAPTOR_IOCARD = "invalid-adaptor-iocard"
    DISCOVERY_MALFORMED_FRU_INFO = "malformed-fru-info"
    DISCOVERY_RETRY = "retry"
    DISCOVERY_THROTTLED = "throttled"
    DISCOVERY_UNDISCOVERED = "undiscovered"
    DISCOVERY_USER_ACKNOWLEDGED = "user-acknowledged"
    DISCOVERY_WAITING_FOR_MGMT_ACK = "waiting-for-mgmt-ack"
    DISCOVERY_WAITING_FOR_USER_ACK = "waiting-for-user-ack"
    FAULT_LEVEL_CLEARED = "cleared"
    FAULT_LEVEL_CONDITION = "condition"
    FAULT_LEVEL_CRITICAL = "critical"
    FAULT_LEVEL_INFO = "info"
    FAULT_LEVEL_MAJOR = "major"
    FAULT_LEVEL_MINOR = "minor"
    FAULT_LEVEL_WARNING = "warning"
    FW_OPER_STATE_ACTIVATING = "activating"
    FW_OPER_STATE_BAD_IMAGE = "bad-image"
    FW_OPER_STATE_FAILED = "failed"
    FW_OPER_STATE_PENDING_NEXT_BOOT = "pending-next-boot"
    FW_OPER_STATE_READY = "ready"
    FW_OPER_STATE_REBOOTING = "rebooting"
    FW_OPER_STATE_SCHEDULED = "scheduled"
    FW_OPER_STATE_SET_STARTUP = "set-startup"
    FW_OPER_STATE_THROTTLED = "throttled"
    FW_OPER_STATE_UPDATING = "updating"
    FW_OPER_STATE_UPGRADING = "upgrading"
    OPER_STATE_BIOS_RESTORE = "bios-restore"
    OPER_STATE_CMOS_RESET = "cmos-reset"
    OPER_STATE_COMPUTE_FAILED = "compute-failed"
    OPER_STATE_COMPUTE_MISMATCH = "compute-mismatch"
    OPER_STATE_CONFIG = "config"
    OPER_STATE_CONFIG_FAILURE = "config-failure"
    OPER_STATE_DECOMISSIONING = "decomissioning"
    OPER_STATE_DEGRADED = "degraded"
    OPER_STATE_DIAGNOSTICS = "diagnostics"
    OPER_STATE_DIAGNOSTICS_FAILED = "diagnostics-failed"
    OPER_STATE_DISABLED = "disabled"
    OPER_STATE_DISCOVERY = "discovery"
    OPER_STATE_DISCOVERY_FAILED = "discovery-failed"
    OPER_STATE_INACCESSIBLE = "inaccessible"
    OPER_STATE_INDETERMINATE = "indeterminate"
    OPER_STATE_INOPERABLE = "inoperable"
    OPER_STATE_MAINTENANCE = "maintenance"
    OPER_STATE_MAINTENANCE_FAILED = "maintenance-failed"
    OPER_STATE_OK = "ok"
    OPER_STATE_PENDING_REASSOCIATION = "pending-reassociation"
    OPER_STATE_PENDING_REBOOT = "pending-reboot"
    OPER_STATE_POWER_OFF = "power-off"
    OPER_STATE_POWER_PROBLEM = "power-problem"
    OPER_STATE_REMOVED = "removed"
    OPER_STATE_RESTART = "restart"
    OPER_STATE_TEST = "test"
    OPER_STATE_TEST_FAILED = "test-failed"
    OPER_STATE_THERMAL_PROBLEM = "thermal-problem"
    OPER_STATE_UNASSOCIATED = "unassociated"
    OPER_STATE_UNCONFIG = "unconfig"
    OPER_STATE_UNCONFIG_FAILED = "unconfig-failed"
    OPER_STATE_VOLTAGE_PROBLEM = "voltage-problem"


class ConfigServerFilter(ManagedObject):
    """This is ConfigServerFilter class."""

    consts = ConfigServerFilterConsts()
    naming_props = set([])

    mo_meta = MoMeta("ConfigServerFilter", "configServerFilter", "server-filter", VersionMeta.Version131a, "InputOutput", 0xfffff, [], ["read-only"], [], [], [None])

    prop_meta = {
        "association": MoPropertyMeta("association", "association", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["associated", "establishing", "failed", "none", "removing", "throttled"], []), 
        "chassis_dn": MoPropertyMeta("chassis_dn", "chassisDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x4, 0, 256, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "cpu_arch": MoPropertyMeta("cpu_arch", "cpuArch", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["Dual-Core_Opteron", "Intel_P4_C", "Opteron", "Pentium_4", "Turion_64", "Xeon", "Xeon_MP", "Zen", "any"], []), 
        "decommissioned": MoPropertyMeta("decommissioned", "decommissioned", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["false", "no", "true", "yes"], []), 
        "discovery": MoPropertyMeta("discovery", "discovery", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["complete", "diagnostics-complete", "diagnostics-failed", "diagnostics-in-progress", "efidiagnostics-in-progress", "failed", "fru-identity-indeterminate", "fru-not-ready", "fru-state-indeterminate", "illegal-fru", "in-progress", "insufficiently-equipped", "invalid-adaptor-iocard", "malformed-fru-info", "retry", "throttled", "undiscovered", "user-acknowledged", "waiting-for-mgmt-ack", "waiting-for-user-ack"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []), 
        "domain_dn": MoPropertyMeta("domain_dn", "domainDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x80, 0, 256, None, [], []), 
        "domain_group_dn": MoPropertyMeta("domain_group_dn", "domainGroupDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x100, 0, 256, None, [], []), 
        "domain_name": MoPropertyMeta("domain_name", "domainName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "fault_level": MoPropertyMeta("fault_level", "faultLevel", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x400, None, None, None, ["cleared", "condition", "critical", "info", "major", "minor", "warning"], []), 
        "fw_oper_state": MoPropertyMeta("fw_oper_state", "fwOperState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x800, None, None, None, ["activating", "bad-image", "failed", "pending-next-boot", "ready", "rebooting", "scheduled", "set-startup", "throttled", "updating", "upgrading"], []), 
        "fw_version": MoPropertyMeta("fw_version", "fwVersion", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x1000, 0, 510, None, [], []), 
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x2000, 0, 510, None, [], []), 
        "num_of_adaptors": MoPropertyMeta("num_of_adaptors", "numOfAdaptors", "byte", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x4000, None, None, None, [], []), 
        "num_of_cores": MoPropertyMeta("num_of_cores", "numOfCores", "ushort", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x8000, None, None, None, [], []), 
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10000, None, None, None, ["bios-restore", "cmos-reset", "compute-failed", "compute-mismatch", "config", "config-failure", "decomissioning", "degraded", "diagnostics", "diagnostics-failed", "disabled", "discovery", "discovery-failed", "inaccessible", "indeterminate", "inoperable", "maintenance", "maintenance-failed", "ok", "pending-reassociation", "pending-reboot", "power-off", "power-problem", "removed", "restart", "test", "test-failed", "thermal-problem", "unassociated", "unconfig", "unconfig-failed", "voltage-problem"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x20000, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x40000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "total_memory": MoPropertyMeta("total_memory", "totalMemory", "uint", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x80000, None, None, None, [], []), 
    }

    prop_map = {
        "association": "association", 
        "chassisDn": "chassis_dn", 
        "childAction": "child_action", 
        "cpuArch": "cpu_arch", 
        "decommissioned": "decommissioned", 
        "discovery": "discovery", 
        "dn": "dn", 
        "domainDn": "domain_dn", 
        "domainGroupDn": "domain_group_dn", 
        "domainName": "domain_name", 
        "faultLevel": "fault_level", 
        "fwOperState": "fw_oper_state", 
        "fwVersion": "fw_version", 
        "model": "model", 
        "numOfAdaptors": "num_of_adaptors", 
        "numOfCores": "num_of_cores", 
        "operState": "oper_state", 
        "rn": "rn", 
        "status": "status", 
        "totalMemory": "total_memory", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.association = None
        self.chassis_dn = None
        self.child_action = None
        self.cpu_arch = None
        self.decommissioned = None
        self.discovery = None
        self.domain_dn = None
        self.domain_group_dn = None
        self.domain_name = None
        self.fault_level = None
        self.fw_oper_state = None
        self.fw_version = None
        self.model = None
        self.num_of_adaptors = None
        self.num_of_cores = None
        self.oper_state = None
        self.status = None
        self.total_memory = None

        ManagedObject.__init__(self, "ConfigServerFilter", parent_mo_or_dn, **kwargs)




"""This module contains the general information for CallhomeTestAlert ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class CallhomeTestAlertConsts():
    GROUP_DIAGNOSTIC = "diagnostic"
    GROUP_ENVIRONMENTAL = "environmental"
    GROUP_UNKNOWN = "unknown"
    LEVEL_CRITICAL = "critical"
    LEVEL_DEBUG = "debug"
    LEVEL_FATAL = "fatal"
    LEVEL_MAJOR = "major"
    LEVEL_MINOR = "minor"
    LEVEL_NORMAL = "normal"
    LEVEL_NOTIFY = "notify"
    LEVEL_UNKNOWN = "unknown"
    LEVEL_WARNING = "warning"
    MESSAGE_SUBTYPE_DELTA = "delta"
    MESSAGE_SUBTYPE_FULL = "full"
    MESSAGE_SUBTYPE_GOLDMAJOR = "goldmajor"
    MESSAGE_SUBTYPE_GOLDMINOR = "goldminor"
    MESSAGE_SUBTYPE_GOLDNORMAL = "goldnormal"
    MESSAGE_SUBTYPE_MAJOR = "major"
    MESSAGE_SUBTYPE_MINOR = "minor"
    MESSAGE_SUBTYPE_NOSUBTYPE = "nosubtype"
    MESSAGE_SUBTYPE_TEST = "test"
    MESSAGE_SUBTYPE_UNKNOWN = "unknown"
    MESSAGE_TYPE_CONF = "conf"
    MESSAGE_TYPE_DIAG = "diag"
    MESSAGE_TYPE_ENV = "env"
    MESSAGE_TYPE_INVENTORY = "inventory"
    MESSAGE_TYPE_SYSLOG = "syslog"
    MESSAGE_TYPE_TEST = "test"
    MESSAGE_TYPE_UNKNOWN = "unknown"
    SEND_NOW_FALSE = "false"
    SEND_NOW_NO = "no"
    SEND_NOW_TRUE = "true"
    SEND_NOW_YES = "yes"


class CallhomeTestAlert(ManagedObject):
    """This is CallhomeTestAlert class."""

    consts = CallhomeTestAlertConsts()
    naming_props = set([])

    mo_meta = MoMeta("CallhomeTestAlert", "callhomeTestAlert", "testalert", VersionMeta.Version101a, "InputOutput", 0x3ff, [], ["admin", "operations"], ['callhomeEp'], [], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "description": MoPropertyMeta("description", "description", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x2, 0, 510, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "group": MoPropertyMeta("group", "group", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["diagnostic", "environmental", "unknown"], []), 
        "level": MoPropertyMeta("level", "level", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["critical", "debug", "fatal", "major", "minor", "normal", "notify", "unknown", "warning"], []), 
        "message_subtype": MoPropertyMeta("message_subtype", "messageSubtype", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["delta", "full", "goldmajor", "goldminor", "goldnormal", "major", "minor", "nosubtype", "test", "unknown"], []), 
        "message_type": MoPropertyMeta("message_type", "messageType", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["conf", "diag", "env", "inventory", "syslog", "test", "unknown"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []), 
        "send_now": MoPropertyMeta("send_now", "sendNow", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["false", "no", "true", "yes"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "description": "description", 
        "dn": "dn", 
        "group": "group", 
        "level": "level", 
        "messageSubtype": "message_subtype", 
        "messageType": "message_type", 
        "rn": "rn", 
        "sendNow": "send_now", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.description = None
        self.group = None
        self.level = None
        self.message_subtype = None
        self.message_type = None
        self.send_now = None
        self.status = None

        ManagedObject.__init__(self, "CallhomeTestAlert", parent_mo_or_dn, **kwargs)




"""This module contains the general information for TagInstanceItem ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class TagInstanceItemConsts():
    SRC_DME_CENTRAL_MGR = "central-mgr"
    SRC_DME_IDENTIFIER_MGR = "identifier-mgr"
    SRC_DME_MGMT_CONTROLLER = "mgmt-controller"
    SRC_DME_OPERATION_MGR = "operation-mgr"
    SRC_DME_POLICY_MGR = "policy-mgr"
    SRC_DME_RESOURCE_MGR = "resource-mgr"
    SRC_DME_SERVER_MGR = "server-mgr"
    SRC_DME_SERVICE_REG = "service-reg"
    SRC_DME_STATS_MGR = "stats-mgr"
    SRC_DME_UNKNOWN = "unknown"


class TagInstanceItem(ManagedObject):
    """This is TagInstanceItem class."""

    consts = TagInstanceItemConsts()
    naming_props = set([])

    mo_meta = MoMeta("TagInstanceItem", "tagInstanceItem", "tag-instance-item", VersionMeta.Version151a, "InputOutput", 0xf, [], ["read-only"], [], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "def_dn": MoPropertyMeta("def_dn", "defDn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "def_name": MoPropertyMeta("def_name", "defName", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\.:;=\?@\[\]_\{\|\}~a-zA-Z0-9]{0,32}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "domain_group_dn": MoPropertyMeta("domain_group_dn", "domainGroupDn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "domain_name": MoPropertyMeta("domain_name", "domainName", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "object_name": MoPropertyMeta("object_name", "objectName", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\.:;=\?@\[\]_\{\|\}~a-zA-Z0-9]{0,32}""", [], []), 
        "object_type": MoPropertyMeta("object_type", "objectType", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "org_dn": MoPropertyMeta("org_dn", "orgDn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "src_dme": MoPropertyMeta("src_dme", "srcDme", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["central-mgr", "identifier-mgr", "mgmt-controller", "operation-mgr", "policy-mgr", "resource-mgr", "server-mgr", "service-reg", "stats-mgr", "unknown"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "tagged_object_dn": MoPropertyMeta("tagged_object_dn", "taggedObjectDn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "value": MoPropertyMeta("value", "value", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 64, r"""[a-zA-Z0-9=\[\]!#$%()*+\\,-./:;@_\s{|}~?]+""", [], []), 
        "vendor": MoPropertyMeta("vendor", "vendor", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "defDn": "def_dn", 
        "defName": "def_name", 
        "dn": "dn", 
        "domainGroupDn": "domain_group_dn", 
        "domainName": "domain_name", 
        "objectName": "object_name", 
        "objectType": "object_type", 
        "orgDn": "org_dn", 
        "rn": "rn", 
        "srcDme": "src_dme", 
        "status": "status", 
        "taggedObjectDn": "tagged_object_dn", 
        "value": "value", 
        "vendor": "vendor", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.def_dn = None
        self.def_name = None
        self.domain_group_dn = None
        self.domain_name = None
        self.object_name = None
        self.object_type = None
        self.org_dn = None
        self.src_dme = None
        self.status = None
        self.tagged_object_dn = None
        self.value = None
        self.vendor = None

        ManagedObject.__init__(self, "TagInstanceItem", parent_mo_or_dn, **kwargs)




"""This module contains the general information for StorageScsiLunCtx ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class StorageScsiLunCtxConsts():
    CLONE_STATUS_NOT_APPLICABLE = "not-applicable"
    CLONE_STATUS_UNKNOWN = "unknown"
    LUN_CFG_ACTION_ABORT_REPLICATION = "abort-replication"
    LUN_CFG_ACTION_CREATE_REPLICATION = "create-replication"
    LUN_CFG_ACTION_CREATE_SNAPSHOT = "create-snapshot"
    LUN_CFG_ACTION_DELETE = "delete"
    LUN_CFG_ACTION_DISABLE_REPLICATION = "disable-replication"
    LUN_CFG_ACTION_ENABLE_REPLICATION = "enable-replication"
    LUN_CFG_ACTION_OFFLINE = "offline"
    LUN_CFG_ACTION_ONLINE = "online"
    LUN_CFG_ACTION_RESTORE = "restore"
    LUN_CFG_ACTION_TRIGGERED = "triggered"


class StorageScsiLunCtx(ManagedObject):
    """This is StorageScsiLunCtx class."""

    consts = StorageScsiLunCtxConsts()
    naming_props = set([])

    mo_meta = MoMeta("StorageScsiLunCtx", "storageScsiLunCtx", "lun-ctx", VersionMeta.Version141a, "InputOutput", 0x1f, [], ["admin", "ls-compute", "ls-config", "ls-server", "ls-storage"], ['storageScsiLun'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "clone_status": MoPropertyMeta("clone_status", "cloneStatus", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable", "unknown"], ["0-101"]), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "last_snapshot_id": MoPropertyMeta("last_snapshot_id", "lastSnapshotId", "uint", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "lun_cfg_action": MoPropertyMeta("lun_cfg_action", "lunCfgAction", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["abort-replication", "create-replication", "create-snapshot", "delete", "disable-replication", "enable-replication", "offline", "online", "restore", "triggered"], []), 
        "parent_lun_name": MoPropertyMeta("parent_lun_name", "parentLunName", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "cloneStatus": "clone_status", 
        "dn": "dn", 
        "lastSnapshotId": "last_snapshot_id", 
        "lunCfgAction": "lun_cfg_action", 
        "parentLunName": "parent_lun_name", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.clone_status = None
        self.last_snapshot_id = None
        self.lun_cfg_action = None
        self.parent_lun_name = None
        self.status = None

        ManagedObject.__init__(self, "StorageScsiLunCtx", parent_mo_or_dn, **kwargs)




"""This module contains the general information for EquipmentBreakoutCap ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class EquipmentBreakoutCapConsts():
    pass


class EquipmentBreakoutCap(ManagedObject):
    """This is EquipmentBreakoutCap class."""

    consts = EquipmentBreakoutCapConsts()
    naming_props = set([])

    mo_meta = MoMeta("EquipmentBreakoutCap", "equipmentBreakoutCap", "breakout-cap", VersionMeta.Version141a, "InputOutput", 0x1f, [], [""], ['equipmentSwitchCapProvider', 'equipmentSwitchIOCardCapProvider'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "ext_phy_port_bitmask": MoPropertyMeta("ext_phy_port_bitmask", "extPhyPortBitmask", "string", VersionMeta.Version201k, MoPropertyMeta.READ_ONLY, None, None, None, r"""((p107|p103|p99|p95|p91|p87|p83|p79|p75|p71|p67|p63|p59|p55|p108|p104|p100|p96|p92|p88|p84|p80|p76|p72|p68|p64|p60|p56|p105|p101|p97|p93|p89|p85|p81|p77|p73|p69|p65|p61|p57|p106|p102|p98|p94|p90|p86|p82|p78|p74|p70|p66|p62|p58|all|defaultValue),){0,55}(p107|p103|p99|p95|p91|p87|p83|p79|p75|p71|p67|p63|p59|p55|p108|p104|p100|p96|p92|p88|p84|p80|p76|p72|p68|p64|p60|p56|p105|p101|p97|p93|p89|p85|p81|p77|p73|p69|p65|p61|p57|p106|p102|p98|p94|p90|p86|p82|p78|p74|p70|p66|p62|p58|all|defaultValue){0,1}""", [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "phy_port_bitmask": MoPropertyMeta("phy_port_bitmask", "phyPortBitmask", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((p53|p49|p45|p41|p37|p33|p29|p25|p21|p17|p13|p9|p5|p1|p54|p50|p46|p42|p38|p34|p30|p26|p22|p18|p14|p10|p6|p2|p51|p47|p43|p39|p35|p31|p27|p23|p19|p15|p11|p7|p3|p52|p48|p44|p40|p36|p32|p28|p24|p20|p16|p12|p8|p4|all|defaultValue),){0,55}(p53|p49|p45|p41|p37|p33|p29|p25|p21|p17|p13|p9|p5|p1|p54|p50|p46|p42|p38|p34|p30|p26|p22|p18|p14|p10|p6|p2|p51|p47|p43|p39|p35|p31|p27|p23|p19|p15|p11|p7|p3|p52|p48|p44|p40|p36|p32|p28|p24|p20|p16|p12|p8|p4|all|defaultValue){0,1}""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "extPhyPortBitmask": "ext_phy_port_bitmask", 
        "name": "name", 
        "phyPortBitmask": "phy_port_bitmask", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.ext_phy_port_bitmask = None
        self.name = None
        self.phy_port_bitmask = None
        self.status = None

        ManagedObject.__init__(self, "EquipmentBreakoutCap", parent_mo_or_dn, **kwargs)




"""This module contains the general information for FabricFcSanEp ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FabricFcSanEpConsts():
    ADMIN_STATE_DISABLED = "disabled"
    ADMIN_STATE_ENABLED = "enabled"
    AUTO_NEGOTIATE_FALSE = "false"
    AUTO_NEGOTIATE_NO = "no"
    AUTO_NEGOTIATE_TRUE = "true"
    AUTO_NEGOTIATE_YES = "yes"
    CHASSIS_ID_N_A = "N/A"
    FILL_PATTERN_ARBFF = "arbff"
    FILL_PATTERN_IDLE = "idle"
    IF_ROLE_DIAG = "diag"
    IF_ROLE_FCOE_NAS_STORAGE = "fcoe-nas-storage"
    IF_ROLE_FCOE_STORAGE = "fcoe-storage"
    IF_ROLE_FCOE_UPLINK = "fcoe-uplink"
    IF_ROLE_MGMT = "mgmt"
    IF_ROLE_MONITOR = "monitor"
    IF_ROLE_NAS_STORAGE = "nas-storage"
    IF_ROLE_NETWORK = "network"
    IF_ROLE_NETWORK_FCOE_UPLINK = "network-fcoe-uplink"
    IF_ROLE_SERVER = "server"
    IF_ROLE_SERVICE = "service"
    IF_ROLE_STORAGE = "storage"
    IF_ROLE_UNKNOWN = "unknown"
    IF_TYPE_AGGREGATION = "aggregation"
    IF_TYPE_PHYSICAL = "physical"
    IF_TYPE_UNKNOWN = "unknown"
    IF_TYPE_VIRTUAL = "virtual"
    LIC_STATE_LICENSE_EXPIRED = "license-expired"
    LIC_STATE_LICENSE_GRACEPERIOD = "license-graceperiod"
    LIC_STATE_LICENSE_INSUFFICIENT = "license-insufficient"
    LIC_STATE_LICENSE_OK = "license-ok"
    LIC_STATE_NOT_APPLICABLE = "not-applicable"
    LIC_STATE_UNKNOWN = "unknown"
    OPER_STATE_DOWN = "down"
    OPER_STATE_ERROR_MISCONFIGURED = "error-misconfigured"
    OPER_STATE_ERROR_UNSUPPORTED_MINI_SERVER_PORT = "error-unsupported-mini-server-port"
    OPER_STATE_FAILED = "failed"
    OPER_STATE_UNKNOWN = "unknown"
    OPER_STATE_UP = "up"
    PEER_CHASSIS_ID_N_A = "N/A"
    SWITCH_ID_A = "A"
    SWITCH_ID_B = "B"
    SWITCH_ID_NONE = "NONE"
    SWITCH_ID_MGMT = "mgmt"


class FabricFcSanEp(ManagedObject):
    """This is FabricFcSanEp class."""

    consts = FabricFcSanEpConsts()
    naming_props = set(['slotId', 'portId'])

    mo_meta = MoMeta("FabricFcSanEp", "fabricFcSanEp", "phys-slot-[slot_id]-port-[port_id]", VersionMeta.Version121a, "InputOutput", 0x7ff, [], ["admin", "ext-san-config", "ext-san-policy"], ['fabricFcSan'], ['fabricFcMonSrcEp', 'fabricVsanEp', 'fabricVsanMembership'], ["Add", "Get", "Set"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["disabled", "enabled"], []), 
        "aggr_port_id": MoPropertyMeta("aggr_port_id", "aggrPortId", "uint", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "auto_negotiate": MoPropertyMeta("auto_negotiate", "autoNegotiate", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["false", "no", "true", "yes"], []), 
        "chassis_id": MoPropertyMeta("chassis_id", "chassisId", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["N/A"], ["0-255"]), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version121a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "ep_dn": MoPropertyMeta("ep_dn", "epDn", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "fill_pattern": MoPropertyMeta("fill_pattern", "fillPattern", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["arbff", "idle"], []), 
        "flt_aggr": MoPropertyMeta("flt_aggr", "fltAggr", "ulong", VersionMeta.Version121a, MoPropertyMeta.INTERNAL, None, None, None, None, [], []), 
        "if_role": MoPropertyMeta("if_role", "ifRole", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["diag", "fcoe-nas-storage", "fcoe-storage", "fcoe-uplink", "mgmt", "monitor", "nas-storage", "network", "network-fcoe-uplink", "server", "service", "storage", "unknown"], []), 
        "if_type": MoPropertyMeta("if_type", "ifType", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["aggregation", "physical", "unknown", "virtual"], []), 
        "lic_gp": MoPropertyMeta("lic_gp", "licGP", "ulong", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "lic_state": MoPropertyMeta("lic_state", "licState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["license-expired", "license-graceperiod", "license-insufficient", "license-ok", "not-applicable", "unknown"], []), 
        "locale": MoPropertyMeta("locale", "locale", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|server|chassis|internal|external),){0,5}(defaultValue|unknown|server|chassis|internal|external){0,1}""", [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["down", "error-misconfigured", "error-unsupported-mini-server-port", "failed", "unknown", "up"], []), 
        "oper_state_reason": MoPropertyMeta("oper_state_reason", "operStateReason", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "peer_aggr_port_id": MoPropertyMeta("peer_aggr_port_id", "peerAggrPortId", "uint", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "peer_chassis_id": MoPropertyMeta("peer_chassis_id", "peerChassisId", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["N/A"], ["0-255"]), 
        "peer_dn": MoPropertyMeta("peer_dn", "peerDn", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "peer_port_id": MoPropertyMeta("peer_port_id", "peerPortId", "uint", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "peer_slot_id": MoPropertyMeta("peer_slot_id", "peerSlotId", "uint", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "port_id": MoPropertyMeta("port_id", "portId", "uint", VersionMeta.Version121a, MoPropertyMeta.NAMING, 0x40, None, None, None, [], ["1-108"]), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []), 
        "slot_id": MoPropertyMeta("slot_id", "slotId", "uint", VersionMeta.Version121a, MoPropertyMeta.NAMING, 0x100, None, None, None, [], ["1-5"]), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "switch_id": MoPropertyMeta("switch_id", "switchId", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["A", "B", "NONE", "mgmt"], []), 
        "transport": MoPropertyMeta("transport", "transport", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|ether|dce|fc),){0,4}(defaultValue|unknown|ether|dce|fc){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|lan|san|ipc),){0,4}(defaultValue|unknown|lan|san|ipc){0,1}""", [], []), 
        "usr_lbl": MoPropertyMeta("usr_lbl", "usrLbl", "string", VersionMeta.Version121a, MoPropertyMeta.READ_WRITE, 0x400, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,32}""", [], []), 
        "warnings": MoPropertyMeta("warnings", "warnings", "string", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|none|fc-zoning-enabled|configuration-error),){0,3}(defaultValue|none|fc-zoning-enabled|configuration-error){0,1}""", [], []), 
    }

    prop_map = {
        "adminState": "admin_state", 
        "aggrPortId": "aggr_port_id", 
        "autoNegotiate": "auto_negotiate", 
        "chassisId": "chassis_id", 
        "childAction": "child_action", 
        "dn": "dn", 
        "epDn": "ep_dn", 
        "fillPattern": "fill_pattern", 
        "fltAggr": "flt_aggr", 
        "ifRole": "if_role", 
        "ifType": "if_type", 
        "licGP": "lic_gp", 
        "licState": "lic_state", 
        "locale": "locale", 
        "name": "name", 
        "operState": "oper_state", 
        "operStateReason": "oper_state_reason", 
        "peerAggrPortId": "peer_aggr_port_id", 
        "peerChassisId": "peer_chassis_id", 
        "peerDn": "peer_dn", 
        "peerPortId": "peer_port_id", 
        "peerSlotId": "peer_slot_id", 
        "portId": "port_id", 
        "rn": "rn", 
        "slotId": "slot_id", 
        "status": "status", 
        "switchId": "switch_id", 
        "transport": "transport", 
        "type": "type", 
        "usrLbl": "usr_lbl", 
        "warnings": "warnings", 
    }

    def __init__(self, parent_mo_or_dn, slot_id, port_id, **kwargs):
        self._dirty_mask = 0
        self.slot_id = slot_id
        self.port_id = port_id
        self.admin_state = None
        self.aggr_port_id = None
        self.auto_negotiate = None
        self.chassis_id = None
        self.child_action = None
        self.ep_dn = None
        self.fill_pattern = None
        self.flt_aggr = None
        self.if_role = None
        self.if_type = None
        self.lic_gp = None
        self.lic_state = None
        self.locale = None
        self.name = None
        self.oper_state = None
        self.oper_state_reason = None
        self.peer_aggr_port_id = None
        self.peer_chassis_id = None
        self.peer_dn = None
        self.peer_port_id = None
        self.peer_slot_id = None
        self.status = None
        self.switch_id = None
        self.transport = None
        self.type = None
        self.usr_lbl = None
        self.warnings = None

        ManagedObject.__init__(self, "FabricFcSanEp", parent_mo_or_dn, **kwargs)




"""This module contains the general information for MemoryRuntime ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class MemoryRuntimeConsts():
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class MemoryRuntime(ManagedObject):
    """This is MemoryRuntime class."""

    consts = MemoryRuntimeConsts()
    naming_props = set(['type'])

    mo_meta = MoMeta("MemoryRuntime", "memoryRuntime", "[type]-mem-rt", VersionMeta.Version111a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], ['computeBlade'], ['memoryRuntimeHist'], ["Get"])

    prop_meta = {
        "available": MoPropertyMeta("available", "available", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "available_avg": MoPropertyMeta("available_avg", "availableAvg", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "available_max": MoPropertyMeta("available_max", "availableMax", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "available_min": MoPropertyMeta("available_min", "availableMin", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "cached": MoPropertyMeta("cached", "cached", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "cached_avg": MoPropertyMeta("cached_avg", "cachedAvg", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "cached_max": MoPropertyMeta("cached_max", "cachedMax", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "cached_min": MoPropertyMeta("cached_min", "cachedMin", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "normalized_time_col": MoPropertyMeta("normalized_time_col", "normalizedTimeCol", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "stats_reported": MoPropertyMeta("stats_reported", "statsReported", "int", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "total": MoPropertyMeta("total", "total", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "total_avg": MoPropertyMeta("total_avg", "totalAvg", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "total_max": MoPropertyMeta("total_max", "totalMax", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "total_min": MoPropertyMeta("total_min", "totalMin", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version111a, MoPropertyMeta.NAMING, None, None, None, None, [], []), 
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
    }

    prop_map = {
        "available": "available", 
        "availableAvg": "available_avg", 
        "availableMax": "available_max", 
        "availableMin": "available_min", 
        "cached": "cached", 
        "cachedAvg": "cached_avg", 
        "cachedMax": "cached_max", 
        "cachedMin": "cached_min", 
        "childAction": "child_action", 
        "dn": "dn", 
        "intervals": "intervals", 
        "normalizedTimeCol": "normalized_time_col", 
        "rn": "rn", 
        "statsReported": "stats_reported", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "total": "total", 
        "totalAvg": "total_avg", 
        "totalMax": "total_max", 
        "totalMin": "total_min", 
        "type": "type", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, type, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.available = None
        self.available_avg = None
        self.available_max = None
        self.available_min = None
        self.cached = None
        self.cached_avg = None
        self.cached_max = None
        self.cached_min = None
        self.child_action = None
        self.intervals = None
        self.normalized_time_col = None
        self.stats_reported = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.total = None
        self.total_avg = None
        self.total_max = None
        self.total_min = None
        self.update = None

        ManagedObject.__init__(self, "MemoryRuntime", parent_mo_or_dn, **kwargs)




"""This module contains the general information for FaultSummaryInst ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FaultSummaryInstConsts():
    SEVERITY_CLEARED = "cleared"
    SEVERITY_CONDITION = "condition"
    SEVERITY_CRITICAL = "critical"
    SEVERITY_INFO = "info"
    SEVERITY_MAJOR = "major"
    SEVERITY_MINOR = "minor"
    SEVERITY_WARNING = "warning"


class FaultSummaryInst(ManagedObject):
    """This is FaultSummaryInst class."""

    consts = FaultSummaryInstConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("FaultSummaryInst", "faultSummaryInst", "fault-summary-[name]", VersionMeta.Version131a, "InputOutput", 0x1f, [], ["admin", "fault", "operations"], ['faultDomainEp', 'faultSummaryInst'], ['faultSummaryInst'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "context": MoPropertyMeta("context", "context", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "domain_inst_ref": MoPropertyMeta("domain_inst_ref", "domainInstRef", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "fault_code": MoPropertyMeta("fault_code", "faultCode", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "id": MoPropertyMeta("id", "id", "ulong", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version131a, MoPropertyMeta.NAMING, 0x4, 1, 510, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "severity": MoPropertyMeta("severity", "severity", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["cleared", "condition", "critical", "info", "major", "minor", "warning"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "context": "context", 
        "dn": "dn", 
        "domainInstRef": "domain_inst_ref", 
        "faultCode": "fault_code", 
        "id": "id", 
        "name": "name", 
        "rn": "rn", 
        "severity": "severity", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.context = None
        self.domain_inst_ref = None
        self.fault_code = None
        self.id = None
        self.severity = None
        self.status = None

        ManagedObject.__init__(self, "FaultSummaryInst", parent_mo_or_dn, **kwargs)




"""This module contains the general information for MgmtImportItem ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class MgmtImportItemConsts():
    OP_STATUS_ALL_SUCCESS = "all-success"
    OP_STATUS_DOMAIN_SUSPENDED = "domain-suspended"
    OP_STATUS_FAILED = "failed"
    OP_STATUS_NOT_STARTED = "not-started"
    OP_STATUS_PARTIAL_FAILED = "partial-failed"
    OP_STATUS_WORK_IN_PROGRESS = "work-in-progress"


class MgmtImportItem(ManagedObject):
    """This is MgmtImportItem class."""

    consts = MgmtImportItemConsts()
    naming_props = set(['sysid'])

    mo_meta = MoMeta("MgmtImportItem", "mgmtImportItem", "imp-provider-[sysid]", VersionMeta.Version101a, "InputOutput", 0x1f, [], ["admin"], ['mgmtDataImporter'], ['faultInst'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "local_file": MoPropertyMeta("local_file", "localFile", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 1, 128, None, [], []), 
        "op_status": MoPropertyMeta("op_status", "opStatus", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["all-success", "domain-suspended", "failed", "not-started", "partial-failed", "work-in-progress"], []), 
        "remote_file": MoPropertyMeta("remote_file", "remoteFile", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 1, 128, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "status_report": MoPropertyMeta("status_report", "statusReport", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 512, None, [], []), 
        "sysid": MoPropertyMeta("sysid", "sysid", "uint", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x10, None, None, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "localFile": "local_file", 
        "opStatus": "op_status", 
        "remoteFile": "remote_file", 
        "rn": "rn", 
        "status": "status", 
        "statusReport": "status_report", 
        "sysid": "sysid", 
    }

    def __init__(self, parent_mo_or_dn, sysid, **kwargs):
        self._dirty_mask = 0
        self.sysid = sysid
        self.child_action = None
        self.local_file = None
        self.op_status = None
        self.remote_file = None
        self.status = None
        self.status_report = None

        ManagedObject.__init__(self, "MgmtImportItem", parent_mo_or_dn, **kwargs)




"""This module contains the general information for AdaptorMenloDcePortStatsHist ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class AdaptorMenloDcePortStatsHistConsts():
    MOST_RECENT_FALSE = "false"
    MOST_RECENT_NO = "no"
    MOST_RECENT_TRUE = "true"
    MOST_RECENT_YES = "yes"
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class AdaptorMenloDcePortStatsHist(ManagedObject):
    """This is AdaptorMenloDcePortStatsHist class."""

    consts = AdaptorMenloDcePortStatsHistConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("AdaptorMenloDcePortStatsHist", "adaptorMenloDcePortStatsHist", "[id]", VersionMeta.Version111a, "OutputOnly", 0xf, [], ["read-only"], ['adaptorMenloDcePortStats'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "id": MoPropertyMeta("id", "id", "ulong", VersionMeta.Version111a, MoPropertyMeta.NAMING, None, None, None, None, [], []), 
        "most_recent": MoPropertyMeta("most_recent", "mostRecent", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "rx_pause_cfc": MoPropertyMeta("rx_pause_cfc", "rxPauseCFC", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rx_pause_cfc_delta": MoPropertyMeta("rx_pause_cfc_delta", "rxPauseCFCDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rx_pause_cfc_delta_avg": MoPropertyMeta("rx_pause_cfc_delta_avg", "rxPauseCFCDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rx_pause_cfc_delta_max": MoPropertyMeta("rx_pause_cfc_delta_max", "rxPauseCFCDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rx_pause_cfc_delta_min": MoPropertyMeta("rx_pause_cfc_delta_min", "rxPauseCFCDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rx_pause_pfc": MoPropertyMeta("rx_pause_pfc", "rxPausePFC", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rx_pause_pfc_delta": MoPropertyMeta("rx_pause_pfc_delta", "rxPausePFCDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rx_pause_pfc_delta_avg": MoPropertyMeta("rx_pause_pfc_delta_avg", "rxPausePFCDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rx_pause_pfc_delta_max": MoPropertyMeta("rx_pause_pfc_delta_max", "rxPausePFCDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rx_pause_pfc_delta_min": MoPropertyMeta("rx_pause_pfc_delta_min", "rxPausePFCDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "tx_pause_cfc": MoPropertyMeta("tx_pause_cfc", "txPauseCFC", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "tx_pause_cfc_delta": MoPropertyMeta("tx_pause_cfc_delta", "txPauseCFCDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "tx_pause_cfc_delta_avg": MoPropertyMeta("tx_pause_cfc_delta_avg", "txPauseCFCDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "tx_pause_cfc_delta_max": MoPropertyMeta("tx_pause_cfc_delta_max", "txPauseCFCDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "tx_pause_cfc_delta_min": MoPropertyMeta("tx_pause_cfc_delta_min", "txPauseCFCDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "tx_pause_pfc": MoPropertyMeta("tx_pause_pfc", "txPausePFC", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "tx_pause_pfc_delta": MoPropertyMeta("tx_pause_pfc_delta", "txPausePFCDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "tx_pause_pfc_delta_avg": MoPropertyMeta("tx_pause_pfc_delta_avg", "txPausePFCDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "tx_pause_pfc_delta_max": MoPropertyMeta("tx_pause_pfc_delta_max", "txPausePFCDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "tx_pause_pfc_delta_min": MoPropertyMeta("tx_pause_pfc_delta_min", "txPausePFCDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "id": "id", 
        "mostRecent": "most_recent", 
        "rn": "rn", 
        "rxPauseCFC": "rx_pause_cfc", 
        "rxPauseCFCDelta": "rx_pause_cfc_delta", 
        "rxPauseCFCDeltaAvg": "rx_pause_cfc_delta_avg", 
        "rxPauseCFCDeltaMax": "rx_pause_cfc_delta_max", 
        "rxPauseCFCDeltaMin": "rx_pause_cfc_delta_min", 
        "rxPausePFC": "rx_pause_pfc", 
        "rxPausePFCDelta": "rx_pause_pfc_delta", 
        "rxPausePFCDeltaAvg": "rx_pause_pfc_delta_avg", 
        "rxPausePFCDeltaMax": "rx_pause_pfc_delta_max", 
        "rxPausePFCDeltaMin": "rx_pause_pfc_delta_min", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "txPauseCFC": "tx_pause_cfc", 
        "txPauseCFCDelta": "tx_pause_cfc_delta", 
        "txPauseCFCDeltaAvg": "tx_pause_cfc_delta_avg", 
        "txPauseCFCDeltaMax": "tx_pause_cfc_delta_max", 
        "txPauseCFCDeltaMin": "tx_pause_cfc_delta_min", 
        "txPausePFC": "tx_pause_pfc", 
        "txPausePFCDelta": "tx_pause_pfc_delta", 
        "txPausePFCDeltaAvg": "tx_pause_pfc_delta_avg", 
        "txPausePFCDeltaMax": "tx_pause_pfc_delta_max", 
        "txPausePFCDeltaMin": "tx_pause_pfc_delta_min", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.child_action = None
        self.most_recent = None
        self.rx_pause_cfc = None
        self.rx_pause_cfc_delta = None
        self.rx_pause_cfc_delta_avg = None
        self.rx_pause_cfc_delta_max = None
        self.rx_pause_cfc_delta_min = None
        self.rx_pause_pfc = None
        self.rx_pause_pfc_delta = None
        self.rx_pause_pfc_delta_avg = None
        self.rx_pause_pfc_delta_max = None
        self.rx_pause_pfc_delta_min = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.tx_pause_cfc = None
        self.tx_pause_cfc_delta = None
        self.tx_pause_cfc_delta_avg = None
        self.tx_pause_cfc_delta_max = None
        self.tx_pause_cfc_delta_min = None
        self.tx_pause_pfc = None
        self.tx_pause_pfc_delta = None
        self.tx_pause_pfc_delta_avg = None
        self.tx_pause_pfc_delta_max = None
        self.tx_pause_pfc_delta_min = None

        ManagedObject.__init__(self, "AdaptorMenloDcePortStatsHist", parent_mo_or_dn, **kwargs)




# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from nose.tools import *
import ucscsdk.ucscxmlcodec as xc


def test_001_StorageLocalDiskPartition():
    xml_str = '''
    <storageLocalDiskPartition childAction="deleteNonPresent" descr=""
    dn="org-root/local-disk-config-default/partition" intId="29002" name=""
    order="1" policyLevel="0" policyOwner="local" size="unknown" type="none"/>
    '''

    obj = xc.from_xml_str(xml_str)
    xml_element = obj.to_xml()
    xc.to_xml_str(xml_element)


def test_002_StorageLocalDiskPartition():
    xml_str = '''<configResolveClass cookie="1447403324/24f7c591-2b3e-4bf4-8cee-716d3b4297b1" response="yes"
    classId="storageLocalDiskPartition"> <outConfigs>  <storageLocalDiskPartition childAction="deleteNonPresent"
    descr="" dn="org-root/local-disk-config-default/partition" intId="29002" name="" order="1" policyLevel="0"
    policyOwner="local" size="unknown" type="none"/>  <storageLocalDiskPartition childAction="deleteNonPresent"
    descr="" dn="sys/chassis-1/blade-2/board/storage-SAS-1/local-disk-config/partition" intId="none" name="" order="1"
    policyLevel="0" policyOwner="local" size="unknown" type="none"/> </outConfigs> </configResolveClass>
    '''

    obj = xc.from_xml_str(xml_str)
    xml_element = obj.to_xml()
    xc.to_xml_str(xml_element)


def test_003_StorageLocalDiskPartition():
    xml_str = '''<storageController childAction="deleteNonPresent" controllerStatus="unknown" deviceRaidSupport="yes"
    faultMonitoring="supported" hwRevision="1064E(B3)" id="1" lc="allocated" locationDn=""
    model="SAS1064E PCI-Express Fusion-MPT SAS" oobControllerId="not-applicable" oobInterfaceSupported="no"
    operQualifierReason="N/A" operState="unknown" operability="unknown" pciAddr="01:00.0"
    pciSlot="" perf="unknown" power="unknown" presence="equipped" raidSupport="RAID0, RAID1"
    rebuildRate="unknown" revision="0" rn="storage-SAS-1" serial="" thermal="unknown" type="SAS"
    vendor="LSI Logic   Symbios Logic" voltage="unknown"> <storageLocalDiskConfigDef childAction="deleteNonPresent"
    descr="" flexFlashRAIDReportingState="disable" flexFlashState="disable" intId="none"
    mode="any-configuration" name="" policyLevel="0" policyOwner="local" protectConfig="no"
    rn="local-disk-config"> <storageLocalDiskPartition childAction="deleteNonPresent" descr="" intId="none"
    name="" order="1" policyLevel="0" policyOwner="local" rn="partition" size="unknown" type="none"/>
    </storageLocalDiskConfigDef></storageController>
    '''

    obj = xc.from_xml_str(xml_str)
    xml_element = obj.to_xml()
    xc.to_xml_str(xml_element)



# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from nose.tools import *
from ..connection.info import custom_setup, custom_teardown

import ucscsdk.ucscxmlcodec as xc
import ucscsdk.ucscmo as ucscmo

handle = None

fault_inst_xml_str = '''
<faultInst descr="TCA: etherTxStats totalBytesDelta = 6480,
raised above 0" dn="sys/switch-A/slot-1/switch-ether/port-3/fault-F35275"
status="modified"/>
'''


def setup():
    pass
    # global handle
    # handle = custom_setup()
    # print "create"


def teardown():
    pass
    # custom_teardown(handle)
    # print "delete"


def test_001_create_gmo_from_xml():
    xml = '''
    <testLsA a="1" b="2" c="3" dn="org-root/" rn="">
     <testLsB a="1" b="2" c="3" dn="org-root/" rn="" />
     <testLsC a="1" b="2" c="3" dn="org-root/" rn="" >
      <testLsD a="1" b="2" c="3" dn="org-root/" rn="" />
     </testLsC>
    </testLsA>'''
    obj = xc.from_xml_str(xml)
    assert_equal(obj.__class__.__name__, 'GenericMo')


def test_002_create_gmo_using_param_dict():
    args = {"a": 1, "b": 2, "c": 3}
    obj = ucscmo.GenericMo("testLsA", "org-root", **args)
    obj1 = ucscmo.GenericMo("testLsB", "org-root", **args)
    obj.child_add(obj1)
    elem = obj.to_xml()
    xml_str = xc.to_xml_str(elem)

    expected = b'<testLsA a="1" b="2" c="3" dn="" rn=""><testLsB a="1" b="2" c="3" dn="" rn="" /></testLsA>'

    assert_equal(xml_str, expected)


def test_003_create_gmo_using_param_dict():
    args = {"a": 1, "b": 2, "c": 3, "rn": "parent"}
    obj = ucscmo.GenericMo("testLsA", "org-root", **args)
    obj1 = ucscmo.GenericMo("testLsB", obj.dn, rn="child")
    obj.child_add(obj1)
    elem = obj.to_xml()
    xml_str = xc.to_xml_str(elem)

    expected = b'<testLsA a="1" b="2" c="3" dn="org-root/parent" rn="parent"><testLsB dn="org-root/parent/child" rn="child" /></testLsA>'

    assert_equal(xml_str, expected)


def test_004_create_gmo_using_parent_mo():
    args = {"a": 1, "b": 2, "c": 3, "rn": "parent"}
    obj = ucscmo.GenericMo("testLsA", "org-root", **args)
    obj1 = ucscmo.GenericMo("testLsB", obj, rn="child")
    elem = obj.to_xml()
    xml_str = xc.to_xml_str(elem)

    expected = b'<testLsA a="1" b="2" c="3" dn="org-root/parent" rn="parent"><testLsB dn="org-root/parent/child" rn="child" /></testLsA>'

    assert_equal(xml_str, expected)


def test_005_create_gmo_from_xml():
    xml_str = '''
    <faultInst descr="TCA: etherTxStats totalBytesDelta = 1005,
    raised above 0" dn="sys/chassis-1/slot-1/host/port-2/fault-F35275"
    status="modified"/>
    '''
    gmo = ucscmo.generic_mo_from_xml(xml_str)
    xml_element = gmo.to_xml()
    to_xml_str = xc.to_xml_str(xml_element)


def test_006_gmo_to_mo():
    xml_str = '''
    <faultInst descr="TCA: etherTxStats totalBytesDelta = 1005,
    raised above 0" dn="sys/chassis-1/slot-1/host/port-2/fault-F14530921"
    status="modified"/>
    '''

    gmo = ucscmo.generic_mo_from_xml(xml_str)
    mo = gmo.to_mo()
    assert_equal(mo.code, "F14530921")



"""This module contains the general information for StatsDbMigrationStatus ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class StatsDbMigrationStatusConsts():
    MIGRATE_STATUS_FAIL = "fail"
    MIGRATE_STATUS_IN_PROGRESS = "inProgress"
    MIGRATE_STATUS_PENDING = "pending"
    MIGRATE_STATUS_SKIP = "skip"
    MIGRATE_STATUS_SUCCESS = "success"


class StatsDbMigrationStatus(ManagedObject):
    """This is StatsDbMigrationStatus class."""

    consts = StatsDbMigrationStatusConsts()
    naming_props = set([])

    mo_meta = MoMeta("StatsDbMigrationStatus", "statsDbMigrationStatus", "dbMigrationStatus", VersionMeta.Version111b, "InputOutput", 0x3f, [], ["admin"], ['statsHolder'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111b, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111b, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "migrate_status": MoPropertyMeta("migrate_status", "migrateStatus", "string", VersionMeta.Version111b, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["fail", "inProgress", "pending", "skip", "success"], []), 
        "percentage": MoPropertyMeta("percentage", "percentage", "uint", VersionMeta.Version111b, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111b, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111b, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "migrateStatus": "migrate_status", 
        "percentage": "percentage", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.migrate_status = None
        self.percentage = None
        self.status = None

        ManagedObject.__init__(self, "StatsDbMigrationStatus", parent_mo_or_dn, **kwargs)




"""This module contains the general information for CommSnmpCommunity ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class CommSnmpCommunityConsts():
    pass


class CommSnmpCommunity(ManagedObject):
    """This is CommSnmpCommunity class."""

    consts = CommSnmpCommunityConsts()
    naming_props = set(['community'])

    mo_meta = MoMeta("CommSnmpCommunity", "commSnmpCommunity", "snmp-community-[community]", VersionMeta.Version101a, "InputOutput", 0x3f, [], ["aaa", "admin"], ['commSnmp'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "community": MoPropertyMeta("community", "community", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x2, None, None, r"""[!#$%\)\*\+,\-\./:<=\[\]\^_\{\}~a-zA-Z0-9]{1,32}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "role": MoPropertyMeta("role", "role", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x10, 1, 32, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "community": "community", 
        "dn": "dn", 
        "rn": "rn", 
        "role": "role", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, community, **kwargs):
        self._dirty_mask = 0
        self.community = community
        self.child_action = None
        self.role = None
        self.status = None

        ManagedObject.__init__(self, "CommSnmpCommunity", parent_mo_or_dn, **kwargs)




"""This module contains the general information for EquipmentServerFeatureCap ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class EquipmentServerFeatureCapConsts():
    CMOS_RESET_SUPPORTED_FALSE = "false"
    CMOS_RESET_SUPPORTED_NO = "no"
    CMOS_RESET_SUPPORTED_TRUE = "true"
    CMOS_RESET_SUPPORTED_YES = "yes"
    STORAGE_JBOD_MODE_SUPPORTED_FALSE = "false"
    STORAGE_JBOD_MODE_SUPPORTED_NO = "no"
    STORAGE_JBOD_MODE_SUPPORTED_TRUE = "true"
    STORAGE_JBOD_MODE_SUPPORTED_YES = "yes"


class EquipmentServerFeatureCap(ManagedObject):
    """This is EquipmentServerFeatureCap class."""

    consts = EquipmentServerFeatureCapConsts()
    naming_props = set([])

    mo_meta = MoMeta("EquipmentServerFeatureCap", "equipmentServerFeatureCap", "server-feature-cap", VersionMeta.Version141a, "InputOutput", 0xf, [], ["read-only"], ['equipmentBladeCapProvider', 'equipmentRackUnitCapProvider', 'equipmentServerUnitCapProvider'], [], ["Get"])

    prop_meta = {
        "adaptor_model": MoPropertyMeta("adaptor_model", "adaptorModel", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "cmos_reset_supported": MoPropertyMeta("cmos_reset_supported", "cmosResetSupported", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "max_virtual_drives_per_server": MoPropertyMeta("max_virtual_drives_per_server", "maxVirtualDrivesPerServer", "ushort", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "max_virtual_eth_if_per_server": MoPropertyMeta("max_virtual_eth_if_per_server", "maxVirtualEthIfPerServer", "ushort", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "number_of_server_units": MoPropertyMeta("number_of_server_units", "numberOfServerUnits", "ushort", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "storage_jbod_mode_supported": MoPropertyMeta("storage_jbod_mode_supported", "storageJbodModeSupported", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
    }

    prop_map = {
        "adaptorModel": "adaptor_model", 
        "childAction": "child_action", 
        "cmosResetSupported": "cmos_reset_supported", 
        "dn": "dn", 
        "maxVirtualDrivesPerServer": "max_virtual_drives_per_server", 
        "maxVirtualEthIfPerServer": "max_virtual_eth_if_per_server", 
        "numberOfServerUnits": "number_of_server_units", 
        "rn": "rn", 
        "status": "status", 
        "storageJbodModeSupported": "storage_jbod_mode_supported", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.adaptor_model = None
        self.child_action = None
        self.cmos_reset_supported = None
        self.max_virtual_drives_per_server = None
        self.max_virtual_eth_if_per_server = None
        self.number_of_server_units = None
        self.status = None
        self.storage_jbod_mode_supported = None

        ManagedObject.__init__(self, "EquipmentServerFeatureCap", parent_mo_or_dn, **kwargs)

